@@ -119,6 +119,20 @@ enum {
 
 enum {
     SPICE_MAIN_CAP_SEMI_SEAMLESS_MIGRATE,
+    SPICE_MAIN_CAP_NAME_AND_UUID,
+    SPICE_MAIN_CAP_AGENT_CONNECTED_TOKENS,
+    SPICE_MAIN_CAP_SEAMLESS_MIGRATE,
+};
+
+enum {
+    SPICE_DISPLAY_CAP_SIZED_STREAM,
+    SPICE_DISPLAY_CAP_MONITORS_CONFIG,
+    SPICE_DISPLAY_CAP_COMPOSITE,
+    SPICE_DISPLAY_CAP_A8_SURFACE,
+};
+
+enum {
+    SPICE_INPUTS_CAP_KEY_SCANCODE,
 };
 
 #include <spice/end-packed.h>
